typedef	unsigned long	DWORD;

/*
 * Qt Pointer
 */
typedef void	*QWidgetP;
typedef	void	*QPainterP;
typedef	void	*QImageP;


/*
 * C linkage functions
 */
#ifdef	__cplusplus
extern "C" {
#endif

	/*
	 * Qt side
	 */
	void qtApInit(int argc, char *argv[]);
	void qtApProcessEvents(void);
	void qtShowFatalError(const char *msg);

	QImageP qtCreateShadowImage(DWORD *w, DWORD *h, int *depth, 
				    void **bits, DWORD *stride);
	void qtRedrawScreen(int x, int y, int w, int h);

	/*
	 * X side
	 */
	void qtStartAp(int argc, char *argv[]);
	void qtMouseMotionSendEvent(int x, int y);
	void qtMouseButtonsSendEvent (int iEventType, int iButton);
	void qtPushMouseKeyEvent(void);
	void qtSendKeyEvent (DWORD dwKey, int fDown);


#ifdef __cplusplus
}
#endif

